/**
 * apeman app to verify email.
 * @function apemanAppVerify
 * @param {object} UserVerify - User verify model.
 * @param {object} [options] - Optional settings.
 * @param {function} [options.beforeSend] - Handle before send
 * @param {function} [options.beforeVerify] - Handle before verify
 * @param {function} [options.afterSend] - Handle after send
 * @param {function} [options.afterVerify] - Handle after verify
 * @param {object} [sendSchema=defaultSchema('send')] - JSON schema for send.
 * @param {object} [verifySchema=defaultSchema('verify')] - JSON schema for verify.
 * @returns {function} - Defined app function.
 */

'use strict'


const assert = require('assert')
const schemas = require('./schemas')

const rest = require('apeman-app-rest')

const debug = require('debug')('apeman:react:verify')

const ONE_DAY = 24 * 60 * 60 * 1000

/** @lends create */
function create (UserVerify, options = {}) {
  
  

  assert.ok(UserVerify, 'UserVerify is required.')
  assert.ok(!!(UserVerify.$$inherited && UserVerify.$$inherited.ApUserVerify), 'UserVerify should inherit ApUserVerify.')

  let pathname = options.pathname || '/verify'
  let format = options.format
  let expireDuration = options.expireDuration || ONE_DAY

  return rest(UserVerify, {
    format,
    pathname,
    createSchema: options.createSchema || schemas('recover-create'),
    updateSchema: options.updateSchema || schemas('recover-update'),
    bulkUpdateDisabled: true,
    bulkDestroyDisabled: true,
    relatedDisabled: true,
    relationDisabled: true,
    doList: require('./doing/do_list_verify')({ expireDuration }),
    doCreate: require('./doing/do_create_verify')({ expireDuration }),
    doUpdate: require('./doing/do_update_verify')({})
  })
}

module.exports = create
