/**
 * @function doListVerify
 * @returns {function}
 */
'use strict'

const co = require('co')
const successPayload = require('apeman-app-rest/lib/payloads/success_payload')
const failurePayload = require('apeman-app-rest/lib/payloads/failure_payload')
const apemanmodel = require('apemanmodel')
const doList = require('apeman-app-rest/lib/doing/do_list')
const errors = require('../errors')

/** @lends doListVerify */
function doListVerify (config) {
  const ACTION_NAME = 'list'
  // let success = successPayload(ACTION_NAME)
  let failure = failurePayload(ACTION_NAME)

  return function listVerify (UserVerify, context) {
    const User = UserVerify.getRef('user').model

    let oneUser = apemanmodel.defineOne(User, context.transaction)

    let req = context.req
    return co(function * () {
      let signed = req.signed()
      let hasSign = signed && signed.sign
      if (!hasSign) {
        return failure(errors.signinRequiredError())
      }

      let { userId } = signed.sign
      let user = yield oneUser(userId)
      if (!user) {
        return failure(
          errors.notFoundError(apemanmodel.toType(User), { id: userId })
        )
      }
      let result = yield doList(UserVerify, context)
      if (result.data) {
        result.data = result.data.map(afterData)
      }
      return result
    })
  }
}

let afterData = (data) => {
  delete data.relationships
  let attributes = data.attributes
  delete attributes.token
  return Object.assign(data, { attributes })
}

module.exports = doListVerify
