/**
 * @function doUpdateVerify
 * @param {Object} config - Configuration
 * @returns {function}
 */
'use strict'

const co = require('co')
const errors = require('../errors')
const successPayload = require('apeman-app-rest/lib/payloads/success_payload')
const failurePayload = require('apeman-app-rest/lib/payloads/failure_payload')
const apemanmodel = require('apemanmodel')

/** @lends doUpdateVerify */
function doUpdateVerify (config) {
  const ACTION_NAME = 'update'
  let success = successPayload(ACTION_NAME)
  let failure = failurePayload(ACTION_NAME)

  return function updateVerify (UserVerify, context) {
    const User = UserVerify.getRef('user').model
    let one = apemanmodel.defineOne(UserVerify, context.transaction)
    let update = apemanmodel.defineUpdate(UserVerify, context.transaction)
    let type = apemanmodel.toType(UserVerify)

    let id = context.id
    let { data } = context

    return co(function * () {
      let verify = yield one(id)
      if (!verify) {
        return failure(errors.notFoundError(type, { id }))
      }
      if (verify.token !== String(data.attributes.token)) {
        return failure(errors.tokenInvalidError())
      }

      if (verify.expired) {
        return failure(errors.tokenExpiredError())
      }
      if (verify.done) {
        return failure(errors.tokenExpiredError())
      }

      let updated = yield update(verify, {
        done: true,
        doneAt: new Date()
      })
      let result = success(
        {},
        apemanmodel.toData(UserVerify, updated),
        {}
      )
      result.data = afterData(result.data)
      return result
    })
  }
}

let afterData = (data) => {
  delete data.relationships
  let attributes = data.attributes
  delete attributes.token
  return Object.assign(data, { attributes })
}

module.exports = doUpdateVerify
